@@ -29,7 +29,8 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 VerifyCloudProviderResponse, AccountRepositoryResponse,
                                                 BlueprintValidationResponse, AccountRepositoryDetailsResponse,
                                                 DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse,
-                                                ParameterStoreItem)
+                                                ParameterStoreItem, RepositoryProviderResponse,
+                                                RepositoryRelationshipResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -1084,38 +1085,6 @@ class Colony:
         verify_json = json.loads(res.text)
         return Converters.create_verify_response(verify_json)
 
-    def add_sandbox_repository_to_space(
-            self,
-            space_name: str,
-            account_repository_name: str,
-            branch: str
-    ):
-        request = {
-            "name": account_repository_name,
-            "branch": branch
-        }
-
-        method_url = self._api_root.spaces.space_sandbox_repository(space_name)
-
-        resp = self.session.post(url=method_url, json=request)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
-
-    def add_production_repository_to_space(
-            self,
-            space_name: str,
-            account_repository_name: str,
-            branch: str
-    ):
-        request = {
-            "name": account_repository_name,
-            "branch": branch
-        }
-
-        method_url = self._api_root.spaces.space_production_repository(space_name)
-
-        resp = self.session.post(url=method_url, json=request)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
-
     def get_space_sandbox_repository(self, space_name: str):
         method_url = self._api_root.spaces.space_sandbox_repository(space_name)
         response = self.session.get(url=method_url)
@@ -1134,16 +1103,6 @@ class Colony:
         response_json = json.loads(response.text)
         return Converters.create_space_repository_response(response_json)
 
-    def delete_sandbox_repository_from_space(self, space_name: str):
-        method_url = self._api_root.spaces.space_sandbox_repository(space_name)
-        response = self.session.delete(url=method_url)
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-
-    def delete_production_repository_from_space(self, space_name: str):
-        method_url = self._api_root.spaces.space_production_repository(space_name)
-        response = self.session.delete(url=method_url)
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-
     def get_debugging_pem_file_content(self, space_name: str, sandbox_id: str, instance_id: str) -> str:
         method_url = self._api_root.debugging.get_aws_pem_file(space_name, sandbox_id, instance_id)
         response = self.session.get(url=method_url)
@@ -1223,6 +1182,183 @@ class Colony:
         response_json = json.loads(response.text)
         return Converters.insided_token_model(data=response_json)
 
+    def add_repository_provider_to_account(
+            self,
+            provider_name: str,
+            repository=None,
+            repo_relationship=None
+    ):
+        method_url = self._api_root.settings.repository_providers()
+        request = {
+            "name": provider_name,
+            "type": "github",
+        }
+
+        if repository:
+            repos = [{
+                "name": repository['repository_name'],
+                "allow_sharing": True,
+                "open_access": True,
+                "repository_url": repository['repository_details'].repository_url,
+                "connection_details": {
+                    "token": repository['repository_details'].access_token
+                },
+                "repository_relationships": None
+            }]
+
+            request["repos"]: List[dict] = repos
+
+            if repo_relationship:
+                repository_relationships = [{
+                    "deployment_type": repo_relationship['deployment_type'],
+                    "account_repository_name": repo_relationship['repository_name'],
+                    "branch": repo_relationship['branch'],
+                    "space_name": repo_relationship['space_name'],
+                }]
+
+                request["repos"][0]["repository_relationships"]: List[dict] = repository_relationships
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        return resp.text.replace('"', '')
+
+    def get_repository_provider(
+            self,
+            provider_name: str
+    ) -> RepositoryProviderResponse:
+        method_url = self._api_root.settings.repository_provider(provider_name)
+
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        json_result = json.loads(resp.text)
+        return Converters.create_repository_provider_response(json_result)
+
+    def get_repository_providers(
+            self,
+    ) -> List[RepositoryProviderResponse]:
+        method_url = self._api_root.settings.repository_providers()
+
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        json_result = json.loads(resp.text)
+        return [Converters.create_repository_provider_response(provider) for provider in json_result]
+
+    def delete_repository_provider(
+            self,
+            provider_name: str
+    ):
+        method_url = self._api_root.settings.repository_provider(provider_name)
+
+        resp = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def add_repository_to_account(
+            self,
+            repository_details: BlueprintRepositoryDetails,
+            repository_provider_id: str,
+            repository_name: str,
+            repo_relationship: dict = None
+
+    ):
+        method_url = self._api_root.settings.repositories()
+
+        request = {
+            "provider_id": repository_provider_id,
+            "name": repository_name,
+            "allow_sharing": True,
+            "open_access": True,
+            "repository_url": repository_details.repository_url,
+            "connection_details": {
+                "token": repository_details.access_token
+            },
+        }
+
+        if repo_relationship:
+            repository_relationships = [{
+                "deployment_type": repo_relationship['deployment_type'],
+                "account_repository_name": repo_relationship['repository_name'],
+                "branch": repo_relationship['branch'],
+                "space_name": repo_relationship['space_name'],
+            }]
+
+            request["repository_relationships"]: List[dict] = repository_relationships
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def list_account_repositories(self) -> List[AccountRepositoryResponse]:
+        url = self._api_root.settings.repositories()
+        response = self.session.get(url=url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        json_result = json.loads(response.text)
+        return [Converters.create_account_repository_response(x) for x in json_result]
+
+    def delete_account_repository(self, name: str):
+        url = self._api_root.settings.repository(name)
+        response = self.session.delete(url=url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+    def add_repository_relationship_to_space(
+            self,
+            deployment_type: str,
+            account_repository_name: str,
+            space: str):
+
+        self.__add_repository_relationship(deployment_type, account_repository_name, space, None)
+
+    def add_repository_relationship(
+            self,
+            deployment_type: str,
+            account_repository_name: str,
+            branch: str = None):
+
+        self.__add_repository_relationship(deployment_type, account_repository_name, self.space, branch)
+
+    def __add_repository_relationship(
+            self,
+            deployment_type: str,
+            account_repository_name: str,
+            space: str,
+            branch: str):
+
+        method_url = self._api_root.spaces.add_repository_relationship(space)
+
+        request = {
+            "deployment_type": deployment_type,
+            "account_repository_name": account_repository_name,
+            "branch": branch
+        }
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def get_repository_relationship(
+            self,
+            deployment_type: str
+    ) -> RepositoryRelationshipResponse:
+        method_url = self._api_root.spaces.repository_relationship(self.space, deployment_type)
+
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        json_result = json.loads(resp.text)
+        return Converters.create_repository_relationship_response(json_result)
+
+    def delete_repository_relationship(
+            self,
+            deployment_type: str,
+    ):
+        self.delete_repository_relationship_from_space(deployment_type, self.space)
+
+    def delete_repository_relationship_from_space(
+            self,
+            deployment_type: str,
+            space: str
+    ):
+        method_url = self._api_root.spaces.repository_relationship(space, deployment_type)
+
+        resp = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
 
 class SandboxesHandler:
     def __init__(self):
