@@ -51,7 +51,7 @@ from gateways.common.cs18_api_responses import (
     AccountRepositoryDetailsBranchResponse, AccountRepositoryDetailsResponse,
     SpaceRepositoryResponse, DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse, ParameterStoreItem,
     ParameterStoreValue, ParameterStoreOrigin, LiteralValue, AwsSsmValue, CloudRegionResponse,
-    CloudComputeServiceResponse, InvitedUserDetailsResponse)
+    CloudComputeServiceResponse, InvitedUserDetailsResponse, RepositoryProviderResponse, RepositoryRelationshipResponse)
 
 
 class Converters:
@@ -825,6 +825,62 @@ class Converters:
             errors=[Error(e) for e in repo["errors"]],
         )
 
+    @staticmethod
+    def create_repository_provider_response(repo: dict) -> RepositoryProviderResponse:
+        """
+        Returns RepositoryProviderResponse based on provided dictionary
+        :param repo: dict
+        :return: RepositoryProviderResponse
+        """
+
+        return RepositoryProviderResponse(
+            provider_id=repo["id"],
+            name=repo["name"],
+            details=repo["details"],
+            status=repo["status"],
+            account_id=repo["account_id"],
+            repositories=[Converters.create_account_repository_response for r in repo["repositories"]],
+            errors=[Error(e) for e in repo["errors"]],
+        )
+
+    @staticmethod
+    def create_account_repository_response(repo: dict) -> AccountRepositoryResponse:
+        """
+        Returns AccountRepositoryResponse based on provided dictionary
+        :param repo: dict
+        :return: AccountRepositoryResponse
+        """
+        return AccountRepositoryResponse(
+            repository_id=repo["id"],
+            name=repo["name"],
+            provider_id=repo["provider_id"],
+            allow_sharing=repo["allow_sharing"],
+            open_access=repo["open_access"],
+            account_id=repo["account_id"],
+            is_valid=repo["is_valid"],
+            repository_url=repo["repository_url"],
+            connection_details=repo["connection_details"],
+            errors=[Error(e) for e in repo["errors"]],
+        )
+
+    @staticmethod
+    def create_repository_relationship_response(repo: dict) -> RepositoryRelationshipResponse:
+        """
+        Returns RepositoryRelationshipResponse based on provided dictionary
+        :param repo: dict
+        :return: RepositoryRelationshipResponse
+        """
+
+        return RepositoryRelationshipResponse(
+            repo_relationship_id=repo["id"],
+            space_id=repo["space_id"],
+            deployment_type=repo["deployment_type"],
+            branch=repo["branch"],
+            account_id=repo["account_id"],
+            is_valid=repo["is_valid"],
+            errors=[Error(e) for e in repo["errors"]],
+        )
+
     @staticmethod
     def create_role_list_item_response(role: dict) -> RoleListItemResponse:
         return RoleListItemResponse(name=role["name"])
@@ -924,15 +980,6 @@ class Converters:
             resources_summary=Converters._create_resources_summary_response(verify["resources_summary"]),
         )
 
-    @staticmethod
-    def create_account_repository_response(data: dict) -> AccountRepositoryResponse:
-        return AccountRepositoryResponse(name=data['name'],
-                                         allow_sharing=data['allow_sharing'],
-                                         open_access=data['open_access'],
-                                         repository_url=data['repository_url'],
-                                         repository_type=data['repository_type'],
-                                         errors=[Error(e) for e in data["errors"]])
-
     @staticmethod
     def create_account_repository_details_branch_response(data: dict) -> AccountRepositoryDetailsBranchResponse:
         return AccountRepositoryDetailsBranchResponse(name=data['name'])
